==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/TerminWyplaty.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class TerminWyplaty extends GenericDPSObject {
    /**
     * TERMIN_WYPLATY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * TERMIN_WYPLATY.DZIEN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer dzien;

    /**
     * TERMIN_WYPLATY.TEKST
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return TERMIN_WYPLATY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * TERMIN_WYPLATY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return TERMIN_WYPLATY.DZIEN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getDzien() {
        return dzien;
    }

    /**
     * TERMIN_WYPLATY.DZIEN
     *
     * @param dzien
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDzien(Integer dzien) {
        this.dzien = dzien;
    }

    /**
     * @return TERMIN_WYPLATY.TEKST
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * TERMIN_WYPLATY.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        TerminWyplaty other = (TerminWyplaty) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDzien() == null ? other.getDzien() == null : this.getDzien().equals(other.getDzien()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDzien() == null) ? 0 : getDzien().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dzien=").append(dzien);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/TerminWyplaty.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class TerminWyplaty extends GenericDPSObject {
    /**
     * TERMIN_WYPLATY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * TERMIN_WYPLATY.DZIEN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer dzien;

    /**
     * TERMIN_WYPLATY.TEKST
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String tekst;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return TERMIN_WYPLATY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * TERMIN_WYPLATY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return TERMIN_WYPLATY.DZIEN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getDzien() {
        return dzien;
    }

    /**
     * TERMIN_WYPLATY.DZIEN
     *
     * @param dzien
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDzien(Integer dzien) {
        this.dzien = dzien;
    }

    /**
     * @return TERMIN_WYPLATY.TEKST
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getTekst() {
        return tekst;
    }

    /**
     * TERMIN_WYPLATY.TEKST
     *
     * @param tekst
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTekst(String tekst) {
        this.tekst = tekst == null ? null : tekst.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        TerminWyplaty other = (TerminWyplaty) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDzien() == null ? other.getDzien() == null : this.getDzien().equals(other.getDzien()))
            && (this.getTekst() == null ? other.getTekst() == null : this.getTekst().equals(other.getTekst()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDzien() == null) ? 0 : getDzien().hashCode());
        result = prime * result + ((getTekst() == null) ? 0 : getTekst().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dzien=").append(dzien);
        sb.append(", tekst=").append(tekst);
        sb.append("]");
        return sb.toString();
    }
}
